==> jc-1.4.0.tar.gz: gnu/java/net/protocol/http/ByteArrayResponseBodyReader.h <==
// public class gnu.java.net.protocol.http.ByteArrayResponseBodyReader

// class file dependencies
// @dep_class d55ef16139ed9b12 gnu_java_net_protocol_http_ByteArrayResponseBodyReader
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_ByteArrayResponseBodyReader_H_
#define _JC_gnu_java_net_protocol_http_ByteArrayResponseBodyReader_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Request$object;
struct _jc_gnu_java_net_protocol_http_Response$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object;

typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *);
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, jint);

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$accept$c349366746d37f03(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_gnu_java_net_protocol_http_Request$object *, struct _jc_gnu_java_net_protocol_http_Response$object *);
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *);
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$read$273900c564cfa217(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_byte_array *, jint, jint);
extern _jc_byte_array *_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$toByteArray$3292ac9bfdd8d59a(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$accept$c349366746d37f03;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$read$273900c564cfa217;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$toByteArray$3292ac9bfdd8d59a;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods {
	jboolean	(*accept$c349366746d37f03)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_gnu_java_net_protocol_http_Request$object *, struct _jc_gnu_java_net_protocol_http_Response$object *);
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *);
	void	(*read$273900c564cfa217)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_byte_array *, jint, jint);
	_jc_byte_array	*(*toByteArray$3292ac9bfdd8d59a)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *);
};

// Vtable
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods	gnu_java_net_protocol_http_ByteArrayResponseBodyReader;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs {
	_jc_byte_array	*content;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs {
    _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs	gnu_java_net_protocol_http_ByteArrayResponseBodyReader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs {
	jint	pos;
	jint	len;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs	gnu_java_net_protocol_http_ByteArrayResponseBodyReader;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object {
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_ByteArrayResponseBodyReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_ByteArrayResponseBodyReader_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/protocol/http/ByteArrayResponseBodyReader.h <==
// public class gnu.java.net.protocol.http.ByteArrayResponseBodyReader

// class file dependencies
// @dep_class d55ef16139ed9b12 gnu_java_net_protocol_http_ByteArrayResponseBodyReader
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_protocol_http_ByteArrayResponseBodyReader_H_
#define _JC_gnu_java_net_protocol_http_ByteArrayResponseBodyReader_H_

// Forward structure declarations
struct _jc_gnu_java_net_protocol_http_Request$object;
struct _jc_gnu_java_net_protocol_http_Response$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs;
typedef struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object;

typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable;
typedef const struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype;

// Constructors
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$_init$7f1776288300b98d(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$accept$c349366746d37f03(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_gnu_java_net_protocol_http_Request$object *, struct _jc_gnu_java_net_protocol_http_Response$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$read$273900c564cfa217(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method$toByteArray$3292ac9bfdd8d59a(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$accept$c349366746d37f03;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$read$273900c564cfa217;
extern _jc_method _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$method_info$toByteArray$3292ac9bfdd8d59a;

// Virtual methods structure
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods {
	jboolean	(*accept$c349366746d37f03)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_gnu_java_net_protocol_http_Request$object *, struct _jc_gnu_java_net_protocol_http_Response$object *) _JC_JCNI_ATTR;
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *) _JC_JCNI_ATTR;
	void	(*read$273900c564cfa217)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	_jc_byte_array	*(*toByteArray$3292ac9bfdd8d59a)(_jc_env *, struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vmethods	gnu_java_net_protocol_http_ByteArrayResponseBodyReader;
};

// Vtype
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype {
	_jc_type			type;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs {
	_jc_byte_array	*content;
};

// Reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs {
    _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_refs	gnu_java_net_protocol_http_ByteArrayResponseBodyReader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs {
	jint	pos;
	jint	len;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$sub_nonrefs	gnu_java_net_protocol_http_ByteArrayResponseBodyReader;
};

// Object instance structure
struct _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$object {
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype	*vtype;
	_jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$vtype _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_protocol_http_ByteArrayResponseBodyReader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_protocol_http_ByteArrayResponseBodyReader$class_object;

#endif	/* _JC_gnu_java_net_protocol_http_ByteArrayResponseBodyReader_H_ */
